WAE Country List - DARC
Author: Deutscher Amateur-Radio-Club e. V.

Stay Logged in?
Lost password?

# WAE Country List

Zurück zur Referat-Seite

# Offiziell WAE Country List

Valid Countries
Prefix | Country | valid since
--- | --- | ---
1A | Sovereign Military Order of Malta |
3A | Monaco |
4O | Montenegro | Jun 28, 2006
4U1I | ITU Headquarters Geneva |
4U1V | United Nations Vienna International Center |
9A | Croatia | Jun 26, 1991
9H | Malta |
C3 | Andorra |
CT | Portugal |
CU | Azores |
DL | Germany | Sep17, 1973
E7 | Bosnia & Herzegovina | Oct 10, 1991
EA | Spain |
EA6 | Balearic Islands |
EI | Ireland |
ER | Moldova |
ES | Estonia |
EU | Belarus |
F | France |
G | England |
GD | Isle of Man |
GI | Northern Ireland |
GJ | Jersey Island |
GM | Scotland |
GM/S | Shetland Islands |
GU | Guernsey, Alderney |
GW | Wales |
HA | Hungary |
HB | Switzerland |
HB0 | Liechtenstein |
HV | Vatikan City |
I | Italy |
IS | Sardinia |
IT | Sicily |
JW | Spitzbergen Island |
JW/B | Bear Island |
JX | Jan Mayen |
LA | Norway |
LX | Luxembourg |
LY | Lithuania |
LZ | Bulgaria |
OE | Austria |
OH | Finland |
OH0 | Aland Islands |
OJ0 | Market Reef |
OK | Czech Republic | Jan 1, 1993
OM | Slovakia | Jan 1, 1993
ON | Belgium |
OY | Faroe Islands |
OZ | Denmark |
PA | The Netherlands |
R1FJ | Franz Josef Land |
S5 | Slovenia | Jun 26, 1991
SM | Sweden |
SP | Poland |
SV | Greece |
SV/A | Mount Athos |
SV5 | Dodecanese |
SV9 | Crete Island |
T7 | San Marino |
TA1 | Turkey (European Part) |
TF | Iceland |
TK | Corse Island |
UA | Russia (European Part) |
UA2 | Kaliningrad |
UR | Ukraine |
YL | Latvia |
YO | Romania |
YU | Serbia |
Z6 | Kosovo | Feb 17, 2008
Z3 | Northern Macedonia | Sep 08, 1991
ZA | Albania |
ZB | Gibraltar |

Deleted Countries
Prefix | Country | valid since | valid until
--- | --- | --- | ---
9S4 | Saarland | Nov 8, 1947 | Mar 31, 1957
I1 | Triest |  | Mar 31, 1957
UN | Karelo Finish Republic |  | Jun 30, 1960
DL | Germany |  | Sep 16, 1973
Y2 | German Democratic Republic | Sep 17, 1973 | Oct 2, 1990
UA1N | Karelia | Jul 1, 1960 | Dec 31, 1991
OK | Czechoslovakia |  | Dec 31, 1992
R1MV | Maliy Vysotskij Isl. |  | Feb 17, 2012

Diese Website nutzt ausschließlich technisch erforderliche Cookies. Wir benutzen keine Cookies, die eine Einwilligung erfordern würden. Weitere Informationen finden Sie in unserer Datenschutzerklärung. X